{ config, pkgs, ... }:
{
  imports =
    [
      ../../base.nix
      ./hardware-configuration.nix
    ];

  networking.hostName = "redshirt";
  networking.networkmanager.enable = true;

  # Enable the X11 windowing system.
  services.xserver = {
    enable = true;
    windowManager = {
      qtile.enable = true;
    };
    # Enable touchpad support (enabled default in most desktopManager).
    libinput.enable = true;
  };

  # The NixOS module enables critical components needed to run Hyprland properly, such as: polkit, xdg-desktop-portal-hyprland, graphics drivers, fonts, dconf, xwayland, and adding a proper Desktop Entry to your Display Manager.
  #programs.hyprland = {
  #  enable = true;
  #  package = pkgs.unstable.hyprland;
  #};

  services.xserver.displayManager = {
    lightdm.enable = true;
    #defaultSession = "hyprland";
  };

  # Configure keymap in X11
  services.xserver.layout = "no";

  fonts.fonts = with pkgs; [
    (nerdfonts.override { fonts = [ "FiraCode" "Hack" ]; })
  ];

  sound.enable = true;

  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    pulse.enable = true;
    jack.enable = true;
  };

  users.users.felixalb = {
    extraGroups = [ "networkmanager" ];
  };

  environment.systemPackages = with pkgs; [
    zsh
    neovim
    git
    ripgrep
    rsync
    cifs-utils
  ];

  documentation.man.generateCaches = true;


  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  system.stateVersion = "22.11";

}

